@@ -29,7 +29,6 @@
 # POSSIBILITY OF SUCH DAMAGE.
 
 import struct
-import zlib
 from abc import abstractmethod
 from collections.abc import Generator, Iterable, Iterator, Mapping
 from datetime import datetime
@@ -61,6 +60,7 @@ from .constants import DocumentInformationAttributes as DI
 from .constants import FieldDictionaryAttributes as FA
 from .constants import PageAttributes as PG
 from .errors import PdfReadError, PyPdfError
+from .filters import _decompress_with_limit
 from .generic import (
     ArrayObject,
     BooleanObject,
@@ -833,7 +833,10 @@ class PdfDocCommon:
         return self._get_outline()
 
     def _get_outline(
-        self, node: Optional[DictionaryObject] = None, outline: Optional[Any] = None
+        self,
+        node: Optional[DictionaryObject] = None,
+        outline: Optional[Any] = None,
+        visited: Optional[set[int]] = None,
     ) -> OutlineType:
         if outline is None:
             outline = []
@@ -855,7 +858,15 @@ class PdfDocCommon:
             return outline
 
         # see if there are any more outline items
+        if visited is None:
+            visited = set()
         while True:
+            node_id = id(node)
+            if node_id in visited:
+                logger_warning(f"Detected cycle in outline structure for {node}", __name__)
+                break
+            visited.add(node_id)
+
             outline_obj = self._build_outline_item(node)
             if outline_obj:
                 outline.append(outline_obj)
@@ -863,7 +874,13 @@ class PdfDocCommon:
             # check for sub-outline
             if "/First" in node:
                 sub_outline: list[Any] = []
-                self._get_outline(cast(DictionaryObject, node["/First"]), sub_outline)
+                # Pass a copy to allow multiple outer entries to reference the same inner one.
+                inner_visited = visited.copy()
+                self._get_outline(
+                    node=cast(DictionaryObject, node["/First"]),
+                    outline=sub_outline,
+                    visited=inner_visited,
+                )
                 if sub_outline:
                     outline.append(sub_outline)
 
@@ -1307,7 +1324,6 @@ class PdfDocCommon:
 
     @property
     def xfa(self) -> Optional[dict[str, Any]]:
-        tree: Optional[TreeObject] = None
         retval: dict[str, Any] = {}
         catalog = self.root_object
 
@@ -1325,7 +1341,7 @@ class PdfDocCommon:
                 if isinstance(f, IndirectObject):
                     field = cast(Optional[EncodedStreamObject], f.get_object())
                     if field:
-                        es = zlib.decompress(field._data)
+                        es = _decompress_with_limit(field._data)
                         retval[tag] = es
         return retval
 
